<?php

declare(strict_types=1);

namespace Dedi\SyliusQuotePlugin\Form\Type;

use Sylius\Bundle\MoneyBundle\Form\Type\MoneyType;
use Sylius\Bundle\ResourceBundle\Form\Type\AbstractResourceType;
use Sylius\Bundle\ResourceBundle\Form\Type\ResourceAutocompleteChoiceType;
use Symfony\Component\Form\Extension\Core\Type\IntegerType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Validator\Constraints\NotBlank;

class QuoteItemType extends AbstractResourceType
{
    public function buildForm(FormBuilderInterface $builder, array $options): void
    {
        $builder
            ->add('variant', ResourceAutocompleteChoiceType::class, [
                'label' => false,
                'resource' => 'sylius.product_variant',
                'choice_name' => 'descriptor',
                'choice_value' => 'id',
                'constraints' => [
                    new NotBlank(['groups' => $this->validationGroups]),
                ],
            ])
            ->add('quantity', IntegerType::class, [
                'attr' => ['min' => 1],
                'label' => false,
                'empty_data' => '1',
            ])
            ->add('unitPrice', MoneyType::class, [
                'currency' => $options['currency'],
                'label' => false,
            ])
        ;
    }

    public function configureOptions(OptionsResolver $resolver): void
    {
        parent::configureOptions($resolver);

        $resolver->setDefined(['currency']);
    }

    public function getBlockPrefix(): string
    {
        return 'dedi_quote_item';
    }
}
